%% Image View Panel
% The Image View Panel is a component that displays slices of the opened dataset. 
% The slices can be in the XY, ZX, or ZY dimension, depending on the selected mode in the <ug_gui_toolbar.html Toolbar>. 
% The panel provides a slider and an edit box on the left-hand side, which
% allow you to change the displayed slices. When the opened dataset has only a
% single slice, the slider and the edit box are not displayed.
%
% *Back to* <im_browser_product_page.html *Index*> |*-->*| <im_browser_user_guide.html *User Guide*> |*-->*| <ug_gui_panels.html *Panels*>
%
% 
%% List of possible image layers that may be simultaneously shown in |MIB|: 
% 
% <<images\PanelsImageView.jpg>>
%
% * *Grayscale or multi-channel image*, this layer displays the original grayscale or multi-channel image that is being analyzed
% * *Model layer*, the model layer contains information about the materials of the segmented model or a difference map 
% for correlation analysis (<ug_gui_data_layers.html click to see more
% about the image layers>)
% * *Mask layer*, mask layer is a black and white (bitmap) mask that is
% generated by some of the filters. The mask is a service layer that may be used as a source of shapes for
% segmentation or as an area for local black-and-white thresholding with the <ug_panel_segm.html BW Thresholding tool>.
% * *Selection layer* is a temporary layer used for segmentation. It can be easily modified and is eventually sent to the Mask or Model layers for further analysis
% * *ROI layer*, if Regions of Interest (ROIs) are enabled, they can also be seen in the Image View panel. 
% ROIs allow for the selection and analysis of specific regions within the image.
%
% 
% <<images\mib_layers.jpg>>
% 
%
% Additionally, the colors and transparencies of the |Model|, |Mask|, and |Selection| layers can be individually 
% adjusted using the sliders in the <ug_panel_view_settings.html View Settings panel> and in the <ug_gui_menu_file_preferences.html Preferences dialog> 
% ([class.code]Menu->File->Preferences->Colors[/class]). This allows for customization of the visual representation of these layers
%
%% Mouse actions 
% 
% The Image View Panel allows for various mouse actions to interact with the displayed image. 
% Here are some common mouse actions and their functionalities:
%
% <html>
% <ul>
% <li><span class="kbd">move mouse</span>, by moving the mouse around the image, you can see pixel information and coordinates in 
% the <a href="ug_panel_path.html">Path Panel</a>. This provides details about the specific location of the cursor within the image</li>
% <li><span class="kbd"><img style="height: 1em" src="images\LMB_click.svg"> left mouse click</span>, clicking the left mouse button enables the selection of pixels in the image 
% based on a specified method in the <a href="ug_panel_segm.html">Segmentation Panel</a>. This allows for the identification and marking 
% of specific areas of interest</li>
% <li><span class="kbd"><img style="height: 1em" src="images\RMB_click.svg"> right mouse click</span> + <span class="kbd">move mouse</span>, holding down the right 
% mouse button and moving the mouse activates the pan mode. This allows you to move the image left/right and up/down, providing a way to navigate and explore different parts of the image</li>
% <li><span class="kbd">^ Ctrl</span> + <span class="kbd"><img style="height: 1em" src="images\LMB_click.svg"> left mouse click</span>, 
% holding down the <span class="kbd">^ Ctrl</span> key while clicking the left mouse button removes the selection from the existing selection (i.e. the eraser mode). 
% This is helpful for deselecting specific areas or refining the selection</li>
% <li><span class="kbd">^ Ctrl</span> + <span class="kbd">mouse wheel (Ctrl + Shift + mouse wheel)</span>, changes the size of the brush and other selection tools. 
% This allows for adjusting the size of the selection tool to suit the specific requirements</li>
% <li><span class="kbd">Mouse wheel</span>, scrolling the mouse wheel up or down can perform different actions depending on the settings in the 
% <a href="ug_gui_menu_file_preferences.html">Preferences dialog</a>.
% It can change slices, allowing you to navigate through different slices of a 3D image, or zoom in and out of the image for a closer or wider view</li>
% <li><span class="kbd">&#8679; Shift</span> + <span class="kbd">Mouse wheel</span>, holding down <span class="kbd">&#8679; Shift</span> while scrolling 
% the mouse wheel jumps to 10 slices at a time. The number of slices can be defined from a popup menu that appears during a 
% right mouse click above the slices slider in the Image View Panel. This provides a faster way to navigate through multiple slices</li>
% </ul>
% </html>
% 
% [class.h3]Right mouse click opens a dropdown menu[/class]
%
%% 
% When clicking on an empty area of within this panel an additiona menu
% appears allowing to hide/show the following panels. This allows to
% increase space occupied by the Image view panel
% 
% <<images\PanelsImageView_dropdown.jpg>>
% 
%
%% Key actions
%
% <html>
% <ul>
% <li> <span class="kbd">W</span> key, zoom in to the area under the cursor</li>
% <li> <span class="kbd">Q</span> key, zoom out away from the area under the cursor</li>
% <li> <span class="kbd">mouse wheel</span>, <span class="kbd">&#8679; Shift</span> + <span class="kbd">mouse wheel</span> show next/previous slice</li>
% <li> <span class="kbd">&#8679; Shift</span> + <span class="kbd">mouse wheel</span> jump 10 slices forward/back (to change this step, see below)</li>
% <li> <span class="kbd">&#8593; up</span>, show next slice</li>
% <li> <span class="kbd">&#8595; down</span>, show previous slice</li>
% <li> <span class="kbd">right &#8594; </span>, show next time point</li>
% <li> <span class="kbd">left &#8592; </span>, show previous time point</li>
% </ul>
% </html>
%
% Key shortcuts can be reassigned in <ug_gui_menu_file_preferences.html Menu->File->Preferences->Keyboard shortcuts> [br]
% For full list of key shortcut consult with <ug_gui_shortcuts.html List of key and mouse shortcuts> .
%
%% Drag and drop files
% 
% * *Images*, image files can be loaded by selecting them in a file
% explorer and drag and drop them into the Image View panel.
% * *Models*, model files with the [class.kbd]*.model[/class] extension can
% also be drag-and-dropped to this panel to be loaded as a new model. When
% model files with labels have other extensions, they also can be
% drag-and-dropped into MIB for loading, but the destination should be the
% Segmentation table in the Segmentation panel.
% * *Masks*, mask files with the [class.kbd]*.mask[/class] extension can be
% automatically loaded by drag-and-drop them into the Image view panel.
% * *Annotations*, annotation files [class.kbd]*.ann[/class] files can be automatically loaded by drag-and-drop them into the Image view panel.
%
%% Extra parameters for the change slices slider.
% [target1] This slider is only shown when 3D or 4D datasets are loaded. By default,
% each iteration of the mouse wheel changes the shown image by 1. It is
% possible to modify this. Press _the right mouse button_ on the slider to
% set the desired step.
%
% 
% <<images\PanelsImageViewContext.png>>
% 
%
%
%
% *Back to* <im_browser_product_page.html *Index*> |*-->*| <im_browser_user_guide.html *User Guide*> |*-->*| <ug_gui_panels.html *Panels*>
%
% [cssClasses]
% .dropdown { 
%   font-family: monospace;
% 	border: 1px solid #aaa; 
% 	border-radius: 0.2em; 
% 	background-color: #fff; 
% 	background-color: #e0f5ff; 
% 	background-color: #e8f5e8; 
% 	padding: 0.1em 0.4em; 
% 	font-family: inherit; 
% 	font-size: 1em;
% }
% .kbd { 
%   font-family: monospace;
% 	border: 1px solid #aaa; 
% 	-moz-border-radius: 0.2em; 
% 	-webkit-border-radius: 0.2em; 
% 	border-radius: 0.2em; 
% 	-moz-box-shadow: 0.1em 0.2em 0.2em #ddd; 
% 	-webkit-box-shadow: 0.1em 0.2em 0.2em #ddd; 
% 	box-shadow: 0.1em 0.2em 0.2em #ddd; 
% 	background-color: #f9f9f9; 
% 	background-image: -moz-linear-gradient(top, #eee, #f9f9f9, #eee); 
% 	background-image: -o-linear-gradient(top, #eee, #f9f9f9, #eee); 
% 	background-image: -webkit-linear-gradient(top, #eee, #f9f9f9, #eee); 
% 	background-image: linear-gradient(&#91;&#91;:Template:Linear-gradient/legacy]], #eee, #f9f9f9, #eee); 
% 	padding: 0.1em 0.4em; 
% 	font-family: inherit; 
% 	font-size: 1em;
% }
% .h3 {
% color: #E65100;
% font-size: 12px;
% font-weight: bold;
% }
% .code {
% font-family: monospace;
% font-size: 10pt;
% background: #eee;
% padding: 1pt 3pt;
% }
% [/cssClasses]
%%
% <html>
% <script>
%   var allDetails = document.getElementsByTagName('details');
%   toggle_details(0);
% </script>
% </html>